@@ -879,11 +879,13 @@ input:checked + .slider:before {
 }
 """
 
+
 class HtmlLogGenerator:
     """
     Generates an HTML log file from the given logs. The logs must derive from the logger in the
     format returned by ``Logger.get_logs()``.
     """
+
     class _columns:
         file_path = 'file_path'
         function_name = 'function_name'
@@ -895,7 +897,7 @@ class HtmlLogGenerator:
         thread_name = 'thread_name'
         is_main_thread = 'is_main_thread'
         timestamp = 'timestamp'
-        
+
     def __init__(self, logs: Dict):
         self._orig_tags = logs['log_tags']
         self._log_tags = self._get_log_tags(logs['log_tags'])
@@ -952,14 +954,14 @@ class HtmlLogGenerator:
                 for k, v in self._log_entries.items()
             }
         log_entries = []
-        if len(temp_log_entries.keys()) > 1:
+        if len(temp_log_entries.keys()) > 1 or self._main_thread_id in map(str, temp_log_entries.keys()):
             # Must be multi-threaded
             thread_starts = [(t, le[0][self._columns.timestamp]) for t, le in temp_log_entries.items()
                              if not le[0][self._columns.is_main_thread]]
             thread_starts = sorted(thread_starts, key=lambda x: x[1])
 
             if self._main_thread_id in temp_log_entries.keys():
-                thread_id, timestamp = thread_starts.pop()
+                thread_id, timestamp = thread_starts.pop() if thread_starts else None, None
                 for entry in temp_log_entries.pop(self._main_thread_id):
                     while timestamp and entry[self._columns.timestamp] >= timestamp:
                         log_entries += temp_log_entries.pop(thread_id)
@@ -973,13 +975,12 @@ class HtmlLogGenerator:
                     log_entries += temp_log_entries.pop(thread_id)
         else:
             # Must be only single threaded
-            log_entries = temp_log_entries[self._main_thread_id]
+            log_entries = temp_log_entries[list(temp_log_entries.keys())[0]]
         code_blocks = self._get_code_blocks(log_entries=log_entries,
                                             exclude_files=exclude_files) if include_code else None
 
-
         used_log_tags, log_entries_html = self._get_log_entries(log_entries=log_entries,
-                              code_blocks=code_blocks if include_code else None)
+                                                                code_blocks=code_blocks if include_code else None)
         self._log_tags = {k: v for k, v in self._log_tags.items() if k in used_log_tags}
         code_blocks_html = ''.join([cb['block'] for cb in code_blocks.values()]) if code_blocks else ''
         legend_html = self._legend()
@@ -1255,6 +1256,7 @@ class HtmlLogGenerator:
         """
         Creates the reset button, log entries, and log blocks.
         """
+
         def format_info_block(le: dict):
             timestamp = datetime.fromtimestamp(le[self._columns.timestamp]).strftime('%a %b %-d %-I:%M:%S %p')
             return f'File: {le[self._columns.file_path]}\n' \
