@@ -321,7 +321,7 @@ class Logger(metaclass=_Singleton):
         if self._persistent_logging:
             if isinstance(format_generator, str):
                 generators = {
-                    'html': HtmlLogGenerator
+                    'html': HtmlLogGenerator,
                 }
                 generator_class = generators[format_generator]
             else:
@@ -418,7 +418,7 @@ class Logger(metaclass=_Singleton):
         if isinstance(log_tag, str):
             log_tag = self.default_log_tags[log_tag]
         else:
-            log_tag = log_tag or self.default_exception_tag
+            log_tag = log_tag or self.default_log_tag
         thread = threading.current_thread()
         if lt := self._threads.get(thread.ident):
             no_console, no_persistence = lt.blacklisted(log_tag)
@@ -523,7 +523,7 @@ class Logger(metaclass=_Singleton):
         self._set_rule(log_tag=log_tag, min_level=min_level, blacklist_function=blacklist_function,
                        why=why, num_prev_callers=2)
         yield
-        self._set_rule(log_tag=log_tag, reset=True, num_prev_callers=2)
+        self._set_rule(log_tag=log_tag, reset=True, num_prev_callers=2, why=why)
 
     def set_mode(self, mode: str, log_tag: Union[LogTagBase, str] = None, why: str = ''):
         """
@@ -899,16 +899,15 @@ class Logger(metaclass=_Singleton):
                 msg = f'Resetting rule. There are no restrictions to logging in this rule.'
             else:
                 msg = f'Resetting rule to the default rule.'
-            why = f'{msg} => {why}' if why else msg
         else:
             blacklist_function = self.default_rule
             blacklist_log_tag = None
             msg = f'No rule defined. There are no restrictions to logging in this rule.'
 
-        if why is not False:
+        if why:
+            msg += f' => {why}'
             func, file_path, line_num = self._get_log_info(num_prev_callers=num_prev_callers)
-            why = why or msg
-            self._commit_log(msg=why, log_tag=log_tag, file_path=file_path, line_num=line_num, func=func)
+            self._commit_log(msg=msg, log_tag=log_tag, file_path=file_path, line_num=line_num, func=func)
 
         if thread.ident == self._main_thread.ident:
             for thread in self._threads.values():
